@@ -28,7 +28,7 @@ class MongoBaseModel:
         self.validate_data()
 
     def create(self, take_result=False):
-        self.data['create_at'] = datetime.datetime.now()
+        self.data['create_at'] = datetime.datetime.utcnow()
 
         if take_result:
             return self.collection.insert_one(self.data)
